==> kpmcore-3.1.0.tar.xz: kpmcore-3.1.0/src/jobs/movephysicalvolumejob.h <==
/*************************************************************************
 *  Copyright (C) 2016 by Chantara Tith <tith.chantara@gmail.com>        *
 *                                                                       *
 *  This program is free software; you can redistribute it and/or        *
 *  modify it under the terms of the GNU General Public License as       *
 *  published by the Free Software Foundation; either version 3 of       *
 *  the License, or (at your option) any later version.                  *
 *                                                                       *
 *  This program is distributed in the hope that it will be useful,      *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *  GNU General Public License for more details.                         *
 *                                                                       *
 *  You should have received a copy of the GNU General Public License    *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
 *************************************************************************/

#if !defined(MOVEPHYSICALVOLUMEJOB_H)

#define MOVEPHYSICALVOLUMEJOB_H

#include "core/partition.h"
#include "jobs/job.h"

class LvmDevice;
class Report;

class QString;

class MovePhysicalVolumeJob : public Job
{
public:
    MovePhysicalVolumeJob(LvmDevice& dev, const QList <const Partition*>& partlist);

public:
    bool run(Report& parent) override;
    QString description() const override;


protected:
    LvmDevice& device() {
        return m_Device;
    }
    const LvmDevice& device() const {
        return m_Device;
    }
    const QList <const Partition*>& partList() const {
        return m_PartList;
    }

private:
    LvmDevice& m_Device;
    const QList <const Partition*> m_PartList;
};

#endif

==> kpmcore-4.0.1.tar.xz: kpmcore-4.0.1/src/jobs/movephysicalvolumejob.h <==
/*************************************************************************
 *  Copyright (C) 2016 by Chantara Tith <tith.chantara@gmail.com>        *
 *                                                                       *
 *  This program is free software; you can redistribute it and/or        *
 *  modify it under the terms of the GNU General Public License as       *
 *  published by the Free Software Foundation; either version 3 of       *
 *  the License, or (at your option) any later version.                  *
 *                                                                       *
 *  This program is distributed in the hope that it will be useful,      *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *  GNU General Public License for more details.                         *
 *                                                                       *
 *  You should have received a copy of the GNU General Public License    *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
 *************************************************************************/

#if !defined(KPMCORE_MOVEPHYSICALVOLUMEJOB_H)

#define KPMCORE_MOVEPHYSICALVOLUMEJOB_H

#include "core/partition.h"
#include "jobs/job.h"

class LvmDevice;
class Report;

class QString;

class MovePhysicalVolumeJob : public Job
{
public:
    MovePhysicalVolumeJob(LvmDevice& dev, const QList <const Partition*>& partlist);

public:
    bool run(Report& parent) override;
    QString description() const override;


protected:
    LvmDevice& device() {
        return m_Device;
    }
    const LvmDevice& device() const {
        return m_Device;
    }
    const QList <const Partition*>& partList() const {
        return m_PartList;
    }

private:
    LvmDevice& m_Device;
    const QList <const Partition*> m_PartList;
};

#endif
